﻿//https://code.msdn.microsoft.com/office/Client-side-rendering-code-b2eedf92
(function($) {
    // test is form with client side rendering
    if (typeof(SPClientTemplates) === 'undefined')
        return;

    // configure propery per tab
    var tabs = {
    	"Basic Information": ["Title", "Company", "JobTitle", "OverallSatisfaction"],
        "Sales Region": ["SalesRegion", "SalesDivision", "SalesState"]
    };
    
    // Use "Multi String" javascript to embed the required css 
    var MultiString = function (f) { 
        return f.toString().split('\n').slice(1, -1).join('\n'); 
    } 

    var tabbedForm = {
        formWebPartId: "",

        /*
         * Insert the html/css to render the tabs into the form web part.
         */
        preRender: function(ctx) {
            // only do on pre render for first field
            if (!tabbedForm.formWebPartId) {
                tabbedForm.formWebPartId = "WebPart" + ctx.FormUniqueId;

                // construct the unordered list to represent the tabs, and insert it into the web part div
                var ul = $("<ul/>", {
                    "class": "tabs"
                });
                var keys = Object.keys(tabs);
                for (var i = 0; i < keys.length; i++) {
                    var li = $("<li/>", {
                        "class": (i == 0 ? "active" : "")
                    });
                    li.append($("<a/>", {
                        "id": "anchor" + i,
                        "href": "#" + i
                    }).text(keys[i]));
                    ul.append(li);
                }
                $("#" + tabbedForm.formWebPartId).prepend(ul);
                
                // add css to make it look like tabs
                $("#" + tabbedForm.formWebPartId).addClass("form-webpart").prepend(tabbedForm.getCss());

                // add a click event handler to each of the tabs anchors
                $('.tabs li a').on('click', function(e) {
                    tabbedForm.selectTab($(this).attr('href').replace("#", ""));
                    e.preventDefault();
                });

                // select the first tab
                $(document).ready(function() {
                    tabbedForm.selectTab(0); // set the active tab to 0
                });
            }
        },

        /*
         * As each field is rendered, add and id so it to the row to make it easy to find and hide the row.
         */
        postRender: function(ctx) {
            // get the table cell holding the input control for the field
            var td = $("#" + ctx.ListSchema.Field[0].Name);
            if (td.length === 1) {
                // hide the closest table row
                td.closest("tr").attr('id', 'tr_' + ctx.ListSchema.Field[0].Name).hide();
            }
        },

        /*
         * Show all fields on the selected tab, hide all others, and mark the selected tab as active.
         */
        selectTab: function(index) {
            // get the anchor for the tab
            var anchor = $('#anchor' + index);
            // add active class to the anchor, and remove from all other anchors
            anchor.parent('li').addClass('active').siblings().removeClass('active');

            // hide all fields
            $("#" + tabbedForm.formWebPartId + " [id^='tr_']").hide();

            // loop through fields for active tab and show them
            var keys = Object.keys(tabs);
            var activeTabFields = tabs[keys[index]];
            for (var i = 0; i < activeTabFields.length; i++) {
                $("[id^='tr_" + activeTabFields[i] + "']").show();
            }
        },

        /*
         * Return the CSS as a string.
         */
        getCss: function() {
            return MultiString(function() {/*
            <style type='text/css'>
                .tabs {
                    border-bottom: 1px solid #ddd;
                    content: " ";
                    display: table;
                    margin-bottom: 0px;
                    padding-left: 10px;
                    padding-top: 5px;
                    padding-bottom: 1px;
                    list-style: none;
                    width: 100%;
                    background: #35414f;
                    border-radius: 3px;
                    margin-top: 5px;
                }

                    .tabs > li {
                        float: left;
                        margin-bottom: -1px;
                        position: relative;
                        display: block;
                    }

                        .tabs > li > a {
                            margin-right: 4px;
                            line-height: 1.4285;
                            border: 1px solid grey;
                            position: relative;
                            display: block;
                            padding: 10px 15px;
                            border-top-left-radius: 3px;
                            border-top-right-radius: 3px;
                            background: #93c3cd;
                            color: darkslategray;
                            font-weight: bold;
                        }

                            .tabs > li > a:hover {
                                background: #e1e463;
                            }

                    .tabs a {
                        color: #428bca;
                        text-decoration: none;
                    }

                    .tabs > li.active > a, .tabs > li.active > a:hover, .tabs > li.active > a:focus {
                        color: white;
                        border: 1px solid #db4865;
                        border-bottom-color: transparent;
                        cursor: default;
                        border-top-right-radius: 5px;
                        border-top-left-radius: 5px;
                        background: #db4865;
                        font-weight: bold;
                    }

                .form-webpart {
                    border: 1px solid #93c3cd;
                    padding: 0 15px 20px 5px;
                    border-radius: 3px;
                    min-width: 570px;
                }

                .ms-formtable {
                    margin: 15px;
                }
            </style>
            */});
        }
    };

    var overrides = {
        OnPreRender: tabbedForm.preRender,
        OnPostRender: tabbedForm.postRender
    };

    // also just register for non-MDS and full page loads
    SPClientTemplates.TemplateManager.RegisterTemplateOverrides(overrides);

    // register template overrides for partial page loads if MDS is enabled
    if (typeof _spPageContextInfo != 'undefined' && _spPageContextInfo != null) {
        var baseUrl = (_spPageContextInfo.siteServerRelativeUrl === '/' ? "" : 

_spPageContextInfo.siteServerRelativeUrl);
        var url = baseUrl + '/Style%20Library/TabbedFormCSR.js';

        RegisterModuleInit(url.toLowerCase(), function() {
            SPClientTemplates.TemplateManager.RegisterTemplateOverrides(overrides);
        });
    }

})(jQuery);
